@@ -49,13 +49,12 @@ class Docker(Color):
         return f"{'.'.join(docker_v)}{space_elem}"
 
     def __str__(self):
-        if self.docker_version_enable:
-            if (
-                is_tool("docker")
-                and not docker_status()[0] == "disabled"
-                and isfile(self.dockerfile)
-                or isfile(self.docker_compose)
-            ):
+        if (
+            is_tool("docker")
+            and self.docker_version_enable
+            and not docker_status()[0] == "disabled"
+        ):
+            if isfile(self.dockerfile) or isfile(self.docker_compose):
                 docker_prefix = (
                     f"{Color(self.docker_prefix_color)}"
                     f"{self.docker_prefix_text}{Color().NONE}"
